# wbutils

![GitHub](https://img.shields.io/github/license/ankur-gupta/wbutils?link=https%3A%2F%2Fgithub.com%2Fankur-gupta%2Fwbutils%2Fblob%2Fmain%2FLICENSE)
![build](https://img.shields.io/github/actions/workflow/status/ankur-gupta/wbutils/build.yml)
[![codecov](https://codecov.io/gh/ankur-gupta/wbutils/branch/main/graph/badge.svg?token=U87QBS06CT)](https://codecov.io/gh/ankur-gupta/wbutils)

Utilities for Weights & Biases
